summaryrefslogtreecommitdiffstats
path: root/libksieve
diff options
context:
space:
mode:
Diffstat (limited to 'libksieve')
-rw-r--r--libksieve/parser/lexer.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/libksieve/parser/lexer.cpp b/libksieve/parser/lexer.cpp
index a38c6102..ec868ece 100644
--- a/libksieve/parser/lexer.cpp
+++ b/libksieve/parser/lexer.cpp
@@ -476,9 +476,9 @@ namespace KSieve {
const int identifierLength = mState.cursor - identifierStart;
// Can use the fast tqfromLatin1 here, since identifiers are always
// in the us-ascii subset:
- result += TQString::tqfromLatin1( identifierStart, identifierLength );
+ result += TQString::fromLatin1( identifierStart, identifierLength );
if ( atEnd() || isDelim( *mState.cursor ) )
return true;
@@ -476,9 +476,9 @@ namespace KSieve {
const int identifierLength = mState.cursor - identifierStart;
- // Can use the fast tqfromLatin1 here, since identifiers are always
+ // Can use the fast fromLatin1 here, since identifiers are always
// in the us-ascii subset: